@ECHO OFF
:REM M. Treichler 06/2018 script attempts to 
:REM Check if Win10 version upgrade is possible, perform upgrade, and gather output log.

:REM Command line options /SCANONLY:Y /SCANONLY:N - Default=NO
:REM Command line options /PRIORITY:Low /PRIORITY:Normal /PRIORITY:High - Default=Normal
:REM Command line options /<VARIABLE>:<VALUE>

SETLOCAL
SET DEBUG=N
SET PRODUCT=Win10-Upgrade
SET PVER=10.0
SET PSOURCE=NOTDEFINED
SET PIMAGE=Win10x64
SET INSTLOG=%PRODUCT%.%PVER%.INST.LOG
SET SCANONLY=N
SET PRIORITY=Normal
SET /A INSTERROR=149
SET PEXE=SETUP.EXE
SET INTACT=/Quiet
SET PSOURCE=NOTDEFINED

ECHO OS Version:
VER | FIND "Version"
IF DEFINED ProgramW6432 (SET PROCARC=AMD64& ECHO ProcessorArchitecture: AMD64) ELSE (SET PROCARC=x86& ECHO ProcessorArchitecture: x86)
ECHO ----------------------------

:checkparameters
:: REM Grab the first variable supplied as a whole. Ex. /scheduledexecution:On
set SWITCHPARSE=%1
:: REM Check to see if there are no more switches, if so goto end of parsing, prevents endless loop
IF [%SWITCHPARSE%] == [] goto endswitchparsing
:: REM Reset variables as clean up. 
set SWITCH=
set VALUE=
:: In the SWITCHPARSE variable, grab the two tokens separated
:: by a : and assign the first to SWITCH and the second to VALUE
for /F "tokens=1,2 delims=: " %%a IN ("%SWITCHPARSE%") DO SET SWITCH=%%a&set VALUE=%%b

:: Set switch to value (removing 1st charcter / )
SET %SWITCH:~1%=%VALUE%
SHIFT
:: REM Reset variables as clean up. 
set SWITCH=
set VALUE=
goto checkparameters
:endswitchparsing

IF %DEBUG%==Y ECHO ON & SET

:REM Get OS Version Info
VER | FIND "Version" >%TEMP%\OSVER.TXT & SET /P OSVer= <%TEMP%\OSVER.TXT & DEL %TEMP%\OSVER.TXT
SET OSVer=%OSVer:~27,-1%
SET /A OSRev=%OSVer:~5,5%

ECHO OS Info:
ECHO %OSVer%
ECHO ----------------------------

:REM Check %PIMAGE% junction to OSIM image setup in %PSOURCE%

IF %PSOURCE%==NOTDEFINED ECHO Product Source /PSOURCE: CLO definedefined : N

IF NOT EXIST %PSOURCE%\%PIMAGE%\%PEXE% (
	ECHO %PIMAGE% Setup Detected: N
	ECHO %PSOURCE%\%PIMAGE%\%PEXE% NOT found, verify %PIMAGE% junction to OSIM image deployed to Scalability Servver.
	EXIT 1410
)

IF NOT EXIST %PSOURCE%\%PIMAGE%\sources\install.wim  (
	ECHO %PIMAGE% Install.wim Detected: N
	ECHO %PSOURCE%\%PIMAGE%\sources\install.wim NOT found, verify %PIMAGE% replication has run on Scalability Servver.
	EXIT 1418
)

:REM Get details about Win10 image.
Dism /Get-ImageInfo /ImageFile:%PSOURCE%\%PIMAGE%\sources\install.wim /index:1 | FIND "Version :" >%TEMP%\WIMVER.TXT & SET /P WIMVer= <%TEMP%\WIMVER.TXT & DEL %TEMP%\WIMVER.TXT
SET WIMVer=%WIMVer:~-10%
SET /A WIMRev=%WIMVer:~-5%

ECHO WIM Info:
ECHO %WIMVer%
ECHO ----------------------------

:REM Check OS Revision less than WIM Revision.
IF %OSRev% GEQ %WIMRev% (
	ECHO Installed OS greater/equal to %PIMAGE% image: Y
	EXIT 0
)

IF %SCANONLY%==Y SET SETUPCLO=/Auto Upgrade /Compat ScanOnly
IF %SCANONLY%==N SET SETUPCLO=/Auto Upgrade

ECHO Installing OS upgrade with command "%PSOURCE%\%PIMAGE%\%PEXE% %SETUPCLO% %INTACT% /Priority %PRIORITY% /NoReboot /CopyLogs %TEMP% " :
ECHO Start time: %DATE% %TIME%
%PSOURCE%\%PIMAGE%\%PEXE% %SETUPCLO% %INTACT% /Priority %PRIORITY% /NoReboot /CopyLogs %TEMP%
SET /A INSTERROR=%ERRORLEVEL% 
ECHO Completion time:  %DATE% %TIME%

ECHO ----------------------------
IF %INSTERROR%==3010 ECHO 3010 - A restart is required to complete the install of %PRODUCT%.%PVER% & SET /A INSTERROR=0
ECHO %INSTERROR%  - %PRODUCT%.%PVER% Install errors

IF %INSTERROR%==0 (
	sd_acmd.exe Signal reboot
)

EXIT %INSTERROR%
