@ECHO OFF
:REM M. Treichler 09/2018 script attempts to 
:REM Setup NTFS junction in ITCM's SDMSILIB to OSIM Win10x64 image directory.
:REM SDMSILIB\Win10x64\ will be used by Windows 10 Feature Upgrade/Update.  
:REM Intended to run against ITCM servers that have Win10x64 OSIM image added to BootServer.
:REM Output to ITCM job status.
:REM Command line options /<VARIABLE>:<VALUE>

SETLOCAL
SET DEBUG=N
SET PRODUCT=Win10-Upgrade
SET PVER=10.0
SET INSTLOG=%PRODUCT%.%PVER%.SS.LOG
SET SSIMAGE=Win10x64
SET SSSOURCE=%SDROOT%\..\Server\SDBS\var\managedpc\images
SET SSTARGET=%SDROOT%\ASM\MSILIB
SET /A INSTERROR=0

:checkparameters
:: REM Grab the first variable supplied as a whole. Ex. /scheduledexecution:On
set SWITCHPARSE=%1
:: REM Check to see if there are no more switches, if so goto end of parsing, prevents endless loop
IF [%SWITCHPARSE%] == [] goto endswitchparsing
:: REM Reset variables as clean up. 
set SWITCH=
set VALUE=
:: In the SWITCHPARSE variable, grab the two tokens separated
:: by a : and assign the first to SWITCH and the second to VALUE
for /F "tokens=1,2 delims=: " %%a IN ("%SWITCHPARSE%") DO SET SWITCH=%%a&set VALUE=%%b

:: Set switch to value (removing 1st charcter / )
SET %SWITCH:~1%=%VALUE%
SHIFT
:: REM Reset variables as clean up. 
set SWITCH=
set VALUE=
goto checkparameters
:endswitchparsing

IF %DEBUG%==Y ECHO ON & SET

:REM Check SDMSILIB share created.
ECHO PRE SDMSILIB Share :
NET SHARE | FIND /i "SDMSILIB" 
IF %ERRORLEVEL%==1 SET /A INSTERROR=1419 & ECHO SDMSILIB Share : N

:REM Check SOURCE and TARGET directory before.
ECHO ----------------------------
ECHO PRE %SSSOURCE% :
DIR /B "%SSSOURCE%"
IF EXIST "%SSSOURCE%\%SSIMAGE%\%SSIMAGE%" (
	ECHO ----------------------------
	ECHO PRE %SSIMAGE% :
	DIR /B "%SSSOURCE%\%SSIMAGE%\%SSIMAGE%"
)
ECHO ----------------------------
ECHO PRE %SSTARGET% :
DIR /B "%SSTARGET%"
ECHO ----------------------------

MKLINK /J  "%SSTARGET%\%SSIMAGE%" "%SSSOURCE%\%SSIMAGE%\%SSIMAGE%"

:REM Check SOURCE and TARGET directory after.
ECHO ----------------------------
ECHO POST %SSSOURCE% :
DIR /B "%SSSOURCE%"
IF EXIST "%SSSOURCE%\%SSIMAGE%\%SSIMAGE%" (
	ECHO ----------------------------
	ECHO POST %SSIMAGE% :
	DIR /B "%SSSOURCE%\%SSIMAGE%\%SSIMAGE%"
)
ECHO ----------------------------
ECHO POST %SSTARGET% :
DIR /B "%SSTARGET%"
ECHO ----------------------------

EXIT %INSTERROR%
